# matrixCalc
Ide o zápočtový program pre predmet Programovanie 1 na Matfyze.
Program robí základné operácie s maticami:
- sčítanie/odčítanie
- násobenie skalárom, maticou
- úprava na REF a RREF tvar
- ďalšie